@@ -5,13 +5,16 @@
 ##############################################################
 
 # Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-# Version: 0.4.4-8
+# Version: 0.4.4-10
 
 import os
 import sys
 import time
 
 from PyQt4 import QtGui,QtCore
+from PyQt4.QtCore import SIGNAL, Qt
+from PyQt4.QtGui import *
+
 from smsconGUIelements import *
 
 ##############################################################
@@ -148,7 +151,7 @@ else:
           quit()
       else:
           # logging.info('user settings succesfully loaded from "%s" file' % ConfigFile) 
-          message = 'SMSCON settings succesfully loaded.'
+          message = 'SMSCON settings succesfully copied and loaded.'
           showMessage(message)
   f.close()
 
@@ -242,27 +245,36 @@ class MyForm(QtGui.QMainWindow):
                 QtCore.QObject.connect(self.ui.btnBoot, QtCore.SIGNAL('clicked()'), self.doBoot)
                 QtCore.QObject.connect(self.ui.btnUnBoot, QtCore.SIGNAL('clicked()'), self.doUnBoot)
                   # Test
-                QtCore.QObject.connect(self.ui.btnTestMail, QtCore.SIGNAL('clicked()'), self.doSendTestMail)
+                QtCore.QObject.connect(self.ui.btnTestMail1, QtCore.SIGNAL('clicked()'), self.doSendTestMail1)
                 QtCore.QObject.connect(self.ui.btnTestMail2, QtCore.SIGNAL('clicked()'), self.doSendTestMail2)
+                QtCore.QObject.connect(self.ui.btnTestGPS1, QtCore.SIGNAL('clicked()'), self.doSendTestGPS1)
+                QtCore.QObject.connect(self.ui.btnTestGPS2, QtCore.SIGNAL('clicked()'), self.doSendTestGPS2)
+                QtCore.QObject.connect(self.ui.btnTestCall, QtCore.SIGNAL('clicked()'), self.doSendTestCall)
+                QtCore.QObject.connect(self.ui.btnTestSMS, QtCore.SIGNAL('clicked()'), self.doSendTestSMS)
                 
                 # Connect Menu Buttons 
                   # those do only one action
                 QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
-##                QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
-##                QtCore.QObject.connect(self.ui.actionCredits, QtCore.SIGNAL('triggered()'), self.doCredits)
+                QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
+                QtCore.QObject.connect(self.ui.actionCredits, QtCore.SIGNAL('triggered()'), self.doCredits)
                   
        # Create Methods
+              
+        def doAbout(self):
+             msg = "The SMSCON Editor is a user interface to the configuration of the SMSCON process.\n"
+             msg += "It provides the ability to edit all the options and name the secret pass-phrases of the commands used for controlling the device by the SMSCON.\n"
+             msg += "In addition, it provides an interface to initialise and configure the SMSCON daemon.\n"
+             msg += "For more info see: www.wiki.maemo.org/SMSCON_Editor"
+             QMessageBox.about(self, "About - SMSCON Editor", msg)
 
-        # def doAbout(self):
-            # msg = "SMSCON - Control your N900 through SMS\n\n"
-            # msg += "Version 0.4.6\n\n"
-            # msg += unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser\n\n"
-            # msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010, Christos Zamantzas\n\n"
-            # msg += "Distributed under GPL ver. 3"
-            # QMessageBox.about(self, "About - SMSCON", msg)
-
-        # def doCredits(self):
-        
+        def doCredits(self):
+             msg += unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser (digitalvoid)\n"
+             msg = "Control and Track your N900 through SMS\n\n"
+             msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010, Christos Zamantzas (saturn)\n"
+             msg += "Configuration and Test User Interface for the SMSCON daemon\n\n"
+             msg += "Distributed under GPL ver. 2"
+             QMessageBox.about(self, "Credits - SMSCON & SMSCON Editor", msg)
+                    
         #TAB: INIT
         def doInit(self):
             os.system('sudo smscon -init')
@@ -374,8 +386,9 @@ class MyForm(QtGui.QMainWindow):
             for Line in source:
                 if   Line.startswith("EMAILADDRESS"):
                    destination.write('EMAILADDRESS      = \'%s\'\n' % EmailAddress)
-##                elif Line.startswith("EMAILFROM"):
+                elif Line.startswith("EMAILFROM"):
 ##                   destination.write('EMAILFROM         = \'%s\'\n' % EmailFrom)
+                   destination.write('EMAILFROM         = \'%s\'\n' % EmailAddress) # temp solution until we find space in GUI.
                 elif Line.startswith("USER"):
                    destination.write('USER              = \'%s\'\n' % EmailUsername)
                 elif Line.startswith("PASSWORD"):
@@ -514,18 +527,38 @@ class MyForm(QtGui.QMainWindow):
             doUpdateConfig()
 
         #TAB: TESTING
-          #FIXME: add more commands.
-        def doSendTestMail(self):
+        def doSendTestMail1(self):
             os.system('sudo smscon -test email1')
-            message = 'A test email has been sent.'
+            message = 'TEST INITIATED: An email has been sent.'
             showMessage(message)
             
         def doSendTestMail2(self):
             os.system('sudo smscon -test email2')
-            message = 'A test email with a picture taken with the front camera has been sent.'
+            message = 'TEST INITIATED: An email with a picture taken with the front camera has been sent.'
+            showMessage(message)
+
+        def doSendTestGPS1(self):
+            os.system('sudo smscon -test gps1')
+            message = 'TEST INITIATED: The GPS coordinates will be acquired and will be send once.'
+            showMessage(message)
+
+        def doSendTestGPS2(self):
+            os.system('sudo smscon -test gps2')
+            message = 'TEST INITIATED: The GPS coordinates will be acquired and will be send in regular periods.'
             showMessage(message)
              
+        def doSendTestCall(self):
+            os.system('sudo smscon -test call')
+            message = 'TEST INITIATED: A phonecall to the default number will be initiated.'
+            showMessage(message)
 
+        def doSendTestSMS(self):
+            os.system('sudo smscon -test sms')
+            message = 'TEST INITIATED: An SMS to the default number will be send.'
+            showMessage(message)
+
+            #FIXME: add more commands.
+             
 if __name__ == "__main__":
         #This function means this was run directly, not called from another Python file.
         app = QtGui.QApplication(sys.argv)
